Module: LSync::EventHandler

Included in:
Directory, Method, Script, Server
Defined in:
lib/lsync/event_handler.rb

Overview

Basic event handling and delegation.

Instance Method Summary collapse

Instance Method Details

#abort!(persistent = false) ⇒ Object

Abort the current event handler. Aborting an event handler persistently implies that in the future it will still be aborted; thus calling #try will have no effect.



85
86
87
88
89
# File 'lib/lsync/event_handler.rb', line 85

def abort!(persistent = false)
  @aborted = true if persistent
  
  throw abort_name
end

#fire(event, *args) ⇒ Object

Fire an event which calls all registered event handlers in the order they were defined. The first argument is used to #instance_eval any handlers.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/lsync/event_handler.rb', line 35

def fire(event, *args)
  handled = false
  
  scope = args.shift
  
  if @events && @events[event]
    @events[event].each do |handler|
      handled = true

      if scope
        scope.instance_exec *args, &handler
      else
        handler.call
      end
    end
  end
  
  return handled
end

#on(event, &block) ⇒ Object

Register an event handler which may be triggered when an event is fired.



26
27
28
29
30
31
# File 'lib/lsync/event_handler.rb', line 26

def on(event, &block)
  @events ||= {}

  @events[event] ||= []
  @events[event] << block
end

#try(*arguments) ⇒ Object

Try executing a given block of code and fire appropriate events.

The sequence of events (registered via #on) are as follows: [+:prepare+] Fired before the block is executed. May call #abort! to cancel execution. [+:success+] Fired after the block of code has executed without raising an exception. [+:failure+] Fired if an exception is thrown during normal execution. [+:done+] Fired at the end of execution regardless of failure.

If #abort! has been called in the past, this function returns immediately.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/lsync/event_handler.rb', line 64

def try(*arguments)
  return if @aborted
  
  begin
    catch(abort_name) do
      fire(:prepare, *arguments)
      
      yield
      
      fire(:success, *arguments)
    end
  rescue Exception => error
    # Propagage the exception unless it was handled in some specific way.
    raise unless fire(:failure, *arguments + [error])
  ensure
    fire(:done, *arguments)
  end
end